@@ -8,22 +8,6 @@ from pony.orm import core
 from pony.orm.dbapiprovider import Pool, ProgrammingError
 from pony.orm.dbproviders._postgres import *
 
-class PsycopgTable(PGTable):
-    def create(table, provider, connection, created_tables=None):
-        try: dbschema.Table.create(table, provider, connection, created_tables)
-        except ProgrammingError, e:
-            if e.original_exc.pgcode !='42P07':
-                provider.rollback(connection)
-                raise
-            if core.debug:
-                core.log_orm('ALREADY EXISTS: %s' % e.args[0])
-                core.log_orm('ROLLBACK')
-            provider.rollback(connection)
-        else: provider.commit(connection)
-
-class PsycopgSchema(PGSchema):
-    table_class = PsycopgTable
-
 class PsycopgPool(Pool):
     def connect(pool):
         if pool.con is None:
@@ -44,7 +28,6 @@ class PsycopgPool(Pool):
 
 class PsycopgProvider(PGProvider):
     dbapi_module = psycopg2
-    dbschema_cls = PsycopgSchema
 
     def inspect_connection(provider, connection):
         provider.server_version = connection.server_version
